@@ -3,10 +3,13 @@ from __future__ import annotations
 
 import asyncio
 import threading
-from typing import Coroutine
+from typing import TYPE_CHECKING
 
 import pytest
 
+if TYPE_CHECKING:
+    from collections.abc import Coroutine
+
 
 class LoopThread(threading.Thread):
     def __init__(self: LoopThread) -> None:
@@ -25,7 +28,7 @@ class LoopThread(threading.Thread):
         self.loop.call_soon_threadsafe(self.loop.create_task, coro)
 
 
-@pytest.fixture()
+@pytest.fixture
 def event_loop() -> LoopThread:
     loop_thread = LoopThread()
     loop_thread.start()
