@@ -7,7 +7,7 @@ import json
 import os
 from collections import defaultdict
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Callable, Generic, cast
+from typing import TYPE_CHECKING, Any, Generic, cast
 
 import pytest
 from str_to_bool import str_to_bool
@@ -15,6 +15,8 @@ from str_to_bool import str_to_bool
 from redux.basic_types import FinishEvent, State
 
 if TYPE_CHECKING:
+    from collections.abc import Callable
+
     from _pytest.fixtures import SubRequest
 
     from redux.main import Store
@@ -128,9 +130,7 @@ class StoreSnapshot(Generic[State]):
         """Monitor the state of the store and take snapshots."""
 
         @self.store.autorun(selector=selector)
-        def _(state: object | None) -> None:
-            if state is None:
-                return
+        def _(state: object) -> None:
             self.take(selector=lambda _: state)
 
     def close(self: StoreSnapshot[State]) -> None:
@@ -145,13 +145,13 @@ class StoreSnapshot(Generic[State]):
             assert not json_path.exists(), f'Snapshot {filename} not taken'
 
 
-@pytest.fixture()
+@pytest.fixture
 def snapshot_prefix() -> str | None:
     """Return the prefix for the snapshots."""
     return None
 
 
-@pytest.fixture()
+@pytest.fixture
 def store_snapshot(
     request: SubRequest,
     store: Store,
